@@ -3,11 +3,11 @@ from typing import Any, Type, cast
 
 import notion_oauth_handler as package
 from notion_oauth_handler.core.consumer import NotionOAuthConsumer
-from notion_oauth_handler.server.response import NotionOAuthResponseFactory
+from notion_oauth_handler.server.view import NotionOAuthRedirectView
 
 
 CONSUMER_ENTRYPOINT_NAME = f'{package.__name__}.consumer'
-RESPONSE_FACTORY_ENTRYPOINT_NAME = f'{package.__name__}.response_factory'
+AUTH_VIEW_ENTRYPOINT_NAME = f'{package.__name__}.auth_view'
 
 
 def list_entrypoint_item_names(entrypoint_name: str) -> list[str]:
@@ -32,10 +32,9 @@ def get_consumer(consumer_name: str) -> NotionOAuthConsumer:
     return consumer
 
 
-def get_response_factory(response_factory_name: str) -> NotionOAuthResponseFactory:
-    response_factory_cls = cast(
-        Type[NotionOAuthResponseFactory],
-        _get_entrypoint(entrypoint_name=RESPONSE_FACTORY_ENTRYPOINT_NAME, item_name=response_factory_name),
+def get_auth_view_cls(auth_view_name: str) -> Type[NotionOAuthRedirectView]:
+    auth_view_cls = cast(
+        Type[NotionOAuthRedirectView],
+        _get_entrypoint(entrypoint_name=AUTH_VIEW_ENTRYPOINT_NAME, item_name=auth_view_name),
     )
-    response_factory = response_factory_cls()
-    return response_factory
+    return auth_view_cls
