@@ -9,7 +9,7 @@ client_secret = ...
 
 [handler]
 consumer = dummy
-response_factory = dummy
+auth_view = default
 """
 
 import configparser
@@ -20,7 +20,7 @@ import attr
 @attr.s(frozen=True, auto_attribs=True, kw_only=True)
 class AppConfiguration:
     consumer_name: str
-    response_factory_name: str
+    auth_view_name: str
     notion_client_id: str = ''
     notion_client_id_key: str = ''
     notion_client_secret: str = ''
@@ -34,7 +34,7 @@ def load_config_from_file(filename: str) -> AppConfiguration:
     config.read(filename)
     return AppConfiguration(
         consumer_name=config['handler'].get('consumer', 'dummy'),
-        response_factory_name=config['handler'].get('response_factory', 'dummy'),
+        auth_view_name=config['handler'].get('auth_view', 'default'),
         notion_client_id=config['notion'].get('client_id', ''),
         notion_client_id_key=config['notion'].get('client_id_key', ''),
         notion_client_secret=config['notion'].get('client_secret', ''),
